package riomhaire.lti.core.business.builder;

import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;

@Slf4j
public class ActionBuilderFactory {
    private Map<Builder,ActionBuilderBuilder> builders = new HashMap<>();

    public ActionBuilderFactory(){
        log.debug("Initializing ActionBuilderFactory");
        setBuilder(Builder.ProcessOidcRequestBuilder,()->new ProcessOidcRequestBuilder());
        setBuilder(Builder.ProcessLTIMessageBuilder,()->new ProcessLtiMessageBuilder());
        setBuilder(Builder.LaunchContentBuilder,()->new LaunchContentBuilder());
    }

    public ActionBuilderFactory setBuilder(Builder builderName, ActionBuilderBuilder actionBuilder) {
       builders.put(builderName,actionBuilder);
       return this;
    }

    public ActionBuilder getBuilder(Builder name)    {
       if( !builders.containsKey(name)) return new NopBuilder();
       return builders.get(name).build();
    }
}
